==> MTurkR_0.5.1.tar.gz: MTurkR/R/BlockWorker.R <==
block <-
BlockWorker <-
BlockWorkers <-
function (workers, reasons, verbose = getOption('MTurkR.verbose'), ...){
    # temporary check for `print` argument (remove after v1.0)
    if('print' %in% names(list(...)) && is.null(verbose))
        verbose <- list(...)$print
    operation <- "BlockWorker"
    if(is.factor(workers))
        workers <- as.character(workers)
    if(is.null(reasons)) 
        stop("Must specify one reason for block for all workers or one reason per worker")
    if(is.factor(reasons))
        reasons <- as.character(reasons)
    if(length(workers) > 1) {
        if(length(reasons) == 1) 
            reasons <- rep(reasons, length(workers))
        else if(!length(workers) == length(reasons)) 
            stop("length(reasons) must equal length(workers) or 1")
    }
    Workers <- setNames(data.frame(matrix(ncol = 3, nrow=length(workers))),
                        c("WorkerId", "Reason", "Valid"))
    for(i in 1:length(workers)) {
        GETparameters <- paste("&WorkerId=", workers[i],
                               "&Reason=", curlEscape(reasons[i]), sep = "")
        request <- request(operation, GETparameters = GETparameters, ...)
        if(is.null(request$valid))
            return(request)
        Workers[i, ] = c(workers[i], reasons[i], request$valid)
        if (request$valid == TRUE & verbose)
            message(i, ": Worker ", workers[i], " Blocked")
        else if (request$valid == FALSE & verbose)
            warning(i,": Invalid Request for worker ",workers[i])
    }
    Workers$Valid <- factor(Workers$Valid, levels=c('TRUE','FALSE'))
    return(Workers)
}

==> MTurkR_0.6.5.1.tar.gz: MTurkR/R/BlockWorker.R <==
block <-
BlockWorker <-
BlockWorkers <-
function (workers, reasons, verbose = getOption('MTurkR.verbose', TRUE), ...){
    # temporary check for `print` argument (remove after v1.0)
    if('print' %in% names(list(...)) && is.null(verbose))
        verbose <- list(...)$print
    operation <- "BlockWorker"
    if(is.factor(workers))
        workers <- as.character(workers)
    if(is.null(reasons)) 
        stop("Must specify one reason for block for all workers or one reason per worker")
    if(is.factor(reasons))
        reasons <- as.character(reasons)
    if(length(workers) > 1) {
        if(length(reasons) == 1) 
            reasons <- rep(reasons, length(workers))
        else if(!length(workers) == length(reasons)) 
            stop("length(reasons) must equal length(workers) or 1")
    }
    Workers <- setNames(data.frame(matrix(ncol = 3, nrow=length(workers))),
                        c("WorkerId", "Reason", "Valid"))
    for(i in 1:length(workers)) {
        GETparameters <- paste("&WorkerId=", workers[i],
                               "&Reason=", curlEscape(reasons[i]), sep = "")
        request <- request(operation, GETparameters = GETparameters, ...)
        if(is.null(request$valid))
            return(request)
        Workers[i, ] = c(workers[i], reasons[i], request$valid)
        if (request$valid == TRUE & verbose)
            message(i, ": Worker ", workers[i], " Blocked")
        else if (request$valid == FALSE & verbose)
            warning(i,": Invalid Request for worker ",workers[i])
    }
    Workers$Valid <- factor(Workers$Valid, levels=c('TRUE','FALSE'))
    return(Workers)
}
